@@ -246,7 +246,7 @@ void DeviceWizard::slotConnectButton()
             tqDebug(i18n("Device getAddress failed: %1").arg(dbuserr.message()));
         if (sel->text(2) == addr)
         {
-            if (connectButton->text() == "C&onnect")
+            if (connectButton->text() == i18n("C&onnect"))
             {
                 connectingDevice.state = ConState::CONNECTING;
                 connectingDevice.address = addr;
@@ -626,6 +626,17 @@ void DeviceWizard::slotInsertDevice(const TQString& path)
 
 
     TQListViewItem *devItem = deviceBox->findItem(addr, 2, TQt::ExactMatch);
+    int nitems=0;
+    TQListViewItem * devItem2 = deviceBox->firstChild();
+    while( devItem2 ) {
+        TQString iname = devItem2->text(1);
+        if ( iname.startsWith(name) )
+                nitems++;
+        devItem2 = devItem2->nextSibling();
+    }
+    // device with same name already exists
+    if (nitems>0)
+        name = name.append("#%1").arg(nitems);
     //device was already setup but is not in the deviceBox
     if (paired && !devItem)
     {
@@ -646,6 +657,7 @@ void DeviceWizard::slotInsertDevice(const TQString& path)
 
     //device was not setup it belongs to the new device list
     TQString mimeType = DeviceMimeConverter::classToMimeType(devclass);
+    TQListViewItem *ndevlist = new TQListViewItem(devicedlg_ext->newdevList, name, addr);
     TQString type;
     if (mimeType == "bluetooth/peripheral-device-class")
     {
@@ -673,15 +685,14 @@ void DeviceWizard::slotInsertDevice(const TQString& path)
     }
     else if (mimeType == "bluetooth/computer-device-class")
     {
-        return;
+        type = i18n("computer");
     }
     else
     {
         type = i18n("unknown");
+        ndevlist->setSelectable(false);
     }
 
-    TQListViewItem *ndevlist = new TQListViewItem(devicedlg_ext->newdevList, name, addr);
-
     TQString iconName = DeviceMimeConverter::classToIconName(devclass);
     KPixmap pix2 = TDEGlobal::iconLoader()->loadIcon(iconName, TDEIcon::Small, 32);
     ndevlist->setPixmap(2, pix2);
@@ -765,6 +776,17 @@ void DeviceWizard::slotSetupNewDevice()
         return;
     }
 
+    if (!confSel->isSelectable())
+    {
+        TQMessageBox::information(this,
+                i18n("Setup device"),
+                i18n("This device is not configurable!"),
+                TQMessageBox::Ok | TQMessageBox::Default,
+                TQMessageBox::NoButton,
+                TQMessageBox::NoButton);
+        return;
+    }
+
     TQString selAddr = confSel->text(1);
     DeviceImpl *newdev;
 
